@import "mixins";

// Typography for the app base template

h1, h2, h3, h4, h5, h6 {
  margin: 10px 0;
  color: #666666;
  .font-smoothing();
}

h1 {
  font-size: 40px;
  font-weight: 500;
  line-height: 60px;
  color: #666666;
}

h2 {
  font-size: 36px;
  font-weight: 300;
  line-height: 40px;
}

h3 {
  font-size: 28px;
  font-weight: 300;
  line-height: 36px;
}

h4 {
  font-size: 28px;
  font-weight: 500;
  line-height: 36px;
}

h5 {
  font-size: 20px;
  font-weight: 300;
  line-height: 28px;
}

h6 {
  font-size: 20px;
  font-weight: 500;
  line-height: 28px;
}

p {
  font-size: 15px;
  color: #666666;
  .font-smoothing();
}

