.tethys-secondary-header {
  position: relative;
  height: 100px;
  background: #1b95dc;
  margin-bottom: 70px;
}
.tethys-secondary-header .image-wrapper {
  position: absolute;
  top: 0;
  left: 0;
  padding: 20px;
  z-index: 100;
}
.tethys-secondary-header .image-wrapper img {
  border-radius: 50%;
  width: 120px;
  background: #1b95dc;
  box-shadow: 0 5px 10px 0px rgba(0, 0, 0, 0.1);
}
.tethys-secondary-header .secondary-title-wrapper {
  float: left;
}
.tethys-secondary-header .secondary-title-wrapper .secondary-title {
  display: block;
  color: white;
  font-size: 40px;
  font-weight: 300;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  padding: 21px 0;
  padding-left: 200px;
}
@media (max-width: 700px) {
  .tethys-secondary-header {
    height: 100px;
    margin-bottom: 0;
  }
  .tethys-secondary-header .image-wrapper {
    position: inline-block;
    padding: 10px 20px;
  }
  .tethys-secondary-header .image-wrapper img {
    width: 80px;
    box-shadow: none;
  }
  .tethys-secondary-header .secondary-title-wrapper .secondary-title {
    font-size: 40px;
    padding: 21px 0;
    padding-left: 120px;
  }
}
body {
  background: #efefef;
}
.header-wrapper {
  margin-top: -90px;
}
.header-wrapper.show {
  margin-top: 0px;
}
.header-wrapper.with-transition {
  -webkit-transition: margin 0.4s ease;
  -moz-transition: margin 0.4s ease;
  -o-transition: margin 0.4s ease;
  -ms-transition: margin 0.4s ease;
  transition: margin 0.4s ease;
}
.tethys-secondary-header {
  height: 100px;
  margin-top: -300px;
  margin-bottom: 350px;
}
.tethys-secondary-header.show {
  margin-top: 0;
  margin-bottom: 50px;
}
.tethys-secondary-header.with-transition {
  -webkit-transition: margin 0.4s ease;
  -moz-transition: margin 0.4s ease;
  -o-transition: margin 0.4s ease;
  -ms-transition: margin 0.4s ease;
  transition: margin 0.4s ease;
}
.tethys-secondary-header .secondary-title-wrapper .secondary-title {
  padding-top: 21px;
  font-size: 40px;
  padding-left: 130px;
}
.tethys-secondary-header .image-wrapper {
  padding-left: 50px;
}
.tethys-secondary-header .image-wrapper img {
  width: 120px;
}
.no-apps-loaded-message {
  width: 50%;
  margin: 100px auto;
  margin-bottom: 150px;
  text-align: center;
}
#app-list {
  position: relative;
  margin: 0 auto;
  width: 1200px;
}
#app-list .app-container {
  width: 200px;
  margin: 20px;
  background: #ffffff;
  border-radius: 5px;
  box-shadow: 0 0 5px 0 rgba(0, 0, 0, 0.1);
}
#app-list .app-container .app-icon img {
  width: 170px;
  margin: 15px;
}
#app-list .app-container .app-title {
  width: 100%;
  padding: 15px;
  padding-top: 0;
  color: #666666;
  text-align: center;
  font-size: 20px;
  font-weight: 500;
  border-radius: 0 0 5px 5px;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
#app-list .app-container .color-effect {
  display: none;
  content: " ";
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  border-radius: 5px;
  background: rgba(255, 255, 255, 0.15);
}
#app-list .app-container:hover {
  box-shadow: 0px 0 10px 0 rgba(0, 0, 0, 0.1);
  text-decoration: none;
}
#app-list .app-container:hover .color-effect {
  display: block;
}
#app-library-curtain {
  position: fixed;
  top: 0;
  left: 0;
  background-color: rgba(255, 255, 255, 0);
  width: 100%;
  height: 100%;
  z-index: -1;
  -webkit-transition: background-color ease-out 0.3s 0.1;
  -moz-transition: background-color ease-out 0.3s 0.1;
  -o-transition: background-color ease-out 0.3s 0.1;
  -ms-transition: background-color ease-out 0.3s 0.1;
  transition: background-color ease-out 0.3s 0.1;
}
#app-library-curtain.show {
  background-color: #ffffff;
  z-index: 200;
}
@media (max-width: 1200px) {
  #app-list {
    width: 960px;
  }
}
@media (max-width: 960px) {
  #app-list {
    width: 720px;
  }
}
@media (max-width: 720px) {
  #app-list {
    width: 480px;
  }
}
@media (max-width: 700px) {
  .tethys-secondary-header {
    height: 100px;
    margin-bottom: 0;
  }
  .tethys-secondary-header.hide {
    margin-top: -300px;
    margin-bottom: 300px;
  }
  .tethys-secondary-header .secondary-title-wrapper .secondary-title {
    padding-left: 50px;
  }
  .tethys-secondary-header .image-wrapper {
    position: inline-block;
    padding: 10px 20px;
  }
  .tethys-secondary-header .image-wrapper img {
    width: 80px;
  }
}
@media (max-width: 480px) {
  #app-list {
    width: 240px;
  }
}
